(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('polythene-core'), require('polythene-utilities')) :
  typeof define === 'function' && define.amd ? define(['exports', 'polythene-core', 'polythene-utilities'], factory) :
  (factory((global.polythene = {}),global['polythene-core'],global['polythene-utilities']));
}(this, (function (exports,polytheneCore,polytheneUtilities) { 'use strict';

  var buttonClasses = {
      component: "pe-text-button",
      super: "pe-button",
      row: "pe-button-row",

      // elements      
      content: "pe-button__content",
      label: "pe-button__label",
      textLabel: "pe-button__text-label",
      wash: "pe-button__wash",
      dropdown: "pe-button__dropdown",

      // states      
      border: "pe-button--border",
      contained: "pe-button--contained",
      disabled: "pe-button--disabled",
      dropdownClosed: "pe-button--dropdown-closed",
      dropdownOpen: "pe-button--dropdown-open",
      extraWide: "pe-button--extra-wide",
      hasDropdown: "pe-button--dropdown",
      highLabel: "pe-button--high-label",
      inactive: "pe-button--inactive",
      raised: "pe-button--raised",
      selected: "pe-button--selected",
      separatorAtStart: "pe-button--separator-start"
  };

  var classes = {
    component: "pe-tabs",

    // elements
    indicator: "pe-tabs__indicator",
    scrollButton: "pe-tabs__scroll-button",
    scrollButtonAtEnd: "pe-tabs__scroll-button-end",
    scrollButtonAtStart: "pe-tabs__scroll-button-start",
    tab: "pe-tab",
    tabContent: "pe-tabs__tab-content",
    tabRow: "pe-tabs__row",

    // states
    activeSelectable: "pe-tabs__active--selectable",
    isAtEnd: "pe-tabs--end",
    isAtStart: "pe-tabs--start",
    isAutofit: "pe-tabs--autofit",
    isMenu: "pe-tabs--menu",
    scrollable: "pe-tabs--scrollable",
    compactTabs: "pe-tabs--compact",
    tabHasIcon: "pe-tabs__tab--icon",
    tabRowCentered: "pe-tabs__row--centered",
    tabRowIndent: "pe-tabs__row--indent",

    // lookup
    label: buttonClasses.label
  };

  var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  var SCROLL_SPEED = 600; // px per second
  var SCROLL_DELAY = .15; // seconds
  var SCROLL_MIN_DURATION = .5; // seconds
  var INDICATOR_SLIDE_MIN_DURATION = .25; // seconds

  var whenCreateDone = function whenCreateDone() {
    return Promise.resolve();
  };

  var getIndex = function getIndex(state, attrs) {
    var attrsSelectedTabIndex = attrs.selectedTabIndex !== undefined ? attrs.selectedTabIndex : attrs.selectedTab !== undefined // deprecated
    ? attrs.selectedTab : undefined;
    return attrsSelectedTabIndex !== undefined ? attrsSelectedTabIndex : Array.isArray(attrs.tabs) ? attrs.tabs.reduce(function (acc, tab, index) {
      return acc === undefined && !tab.disabled ? index : acc;
    }, undefined) : undefined;
  };

  var scrollButtonGetNewIndex = function scrollButtonGetNewIndex(index, tabs) {
    var minTabIndex = 0;
    var maxTabIndex = tabs.length - 1;
    return {
      backward: Math.max(index - 1, minTabIndex),
      forward: Math.min(index + 1, maxTabIndex)
    };
  };

  var handleScrollButtonClick = function handleScrollButtonClick(state, attrs, e, direction) {
    e.stopPropagation();
    e.preventDefault();
    var currentTabIndex = state.selectedTabIndex();
    var newIndex = scrollButtonGetNewIndex(currentTabIndex, state.tabs)[direction];
    if (newIndex !== currentTabIndex) {
      setSelectedTab(state, attrs, newIndex, true);
    } else {
      scrollToTab(state, newIndex);
    }
  };

  var scrollToTab = function scrollToTab(state, tabIndex) {
    var tabs = state.tabs;
    var scroller = state.tabRowEl;
    // Scroll to position of selected tab
    var tabLeft = tabs.slice(0, tabIndex).reduce(function (totalWidth, tabData) {
      return totalWidth + tabData.dom.getBoundingClientRect().width;
    }, 0);
    // Tabs at the far right will not fully move to the left
    // because the scrollable row will stick to the right 
    // to get the max scroll left, we subtract the visible viewport from the scroll width
    var scrollerWidth = scroller.getBoundingClientRect().width; // frame width
    var scrollingWidth = scroller.scrollWidth;
    var maxScroll = scrollingWidth - scrollerWidth;
    var left = state.isRTL ? -1 * Math.min(tabLeft, maxScroll) : Math.min(tabLeft, maxScroll);
    var currentLeft = scroller.scrollLeft;
    if (currentLeft !== left) {
      var duration = Math.abs(currentLeft - left) / SCROLL_SPEED;
      var delaySeconds = SCROLL_DELAY;
      setTimeout(function () {
        polytheneUtilities.scrollTo({
          element: scroller,
          to: left,
          duration: Math.max(SCROLL_MIN_DURATION, duration),
          direction: "horizontal"
        }).then(function () {
          return updateScrollButtons(state);
        });
      }, delaySeconds * 1000);
    }
  };

  var updateScrollButtons = function updateScrollButtons(state) {
    var tabRowEl = state.tabRowEl;
    var scrollLeft = tabRowEl.scrollLeft;
    var currentTabIndex = state.selectedTabIndex();
    var tabsEl = state.tabsEl;
    var minTabIndex = 0;
    var maxTabIndex = state.tabs.length - 1;
    var isAtStart = tabRowEl.scrollLeft === 0 && currentTabIndex === minTabIndex;
    var isAtEnd = scrollLeft >= tabRowEl.scrollWidth - tabsEl.getBoundingClientRect().width - 1 && currentTabIndex === maxTabIndex;
    state.scrollButtonAtStart(isAtStart);
    state.scrollButtonAtEnd(isAtEnd);
  };

  var animateIndicator = function animateIndicator(selectedTabEl, animate, state) {
    var parentRect = state.tabsEl.getBoundingClientRect();
    var rect = selectedTabEl.getBoundingClientRect();
    var buttonSize = state.managesScroll ? rect.height : 0;
    var translateX = state.isRTL ? rect.right - parentRect.right + state.tabRowEl.scrollLeft + buttonSize : rect.left - parentRect.left + state.tabRowEl.scrollLeft - buttonSize;
    var scaleX = 1 / (parentRect.width - 2 * buttonSize) * rect.width;
    var transformCmd = "translate(" + translateX + "px, 0) scaleX(" + scaleX + ")";
    var duration = animate ? INDICATOR_SLIDE_MIN_DURATION : 0;
    var style = state.tabIndicatorEl.style;
    style["transition-duration"] = duration + "s";
    style.transform = transformCmd;
  };

  var setSelectedTab = function setSelectedTab(state, attrs, index, animate) {
    state.selectedTabIndex(index);
    if (!state.tabs.length) return;
    var selectedTabEl = state.tabs[index].dom;
    if (selectedTabEl && state.tabIndicatorEl && state.tabsEl) {
      animateIndicator(selectedTabEl, animate, state);
    }
    if (state.managesScroll) {
      updateScrollButtons(state);
    }
    scrollToTab(state, index);
    if (attrs.onChange) {
      attrs.onChange({
        index: index,
        options: state.tabs[index].attrs,
        el: selectedTabEl
      });
    }
  };

  var sortByLargestWidth = function sortByLargestWidth(a, b) {
    return a < b ? 1 : a > b ? -1 : 0;
  };

  var getInitialState = function getInitialState(vnode, createStream) {
    var state = vnode.state;
    var attrs = vnode.attrs;
    if (attrs.selectedTab !== undefined) {
      polytheneCore.deprecation("Tabs", { option: "selectedTab", newOption: "selectedTabIndex" });
    }
    var tabIndex = getIndex(state, attrs) || 0;
    var selectedTabIndex = createStream(tabIndex);
    var scrollButtonAtStart = createStream(true);
    var scrollButtonAtEnd = createStream(true);
    var registerTabButton = function registerTabButton(state) {
      return function (index, data) {
        return state.tabs[index] = data;
      };
    };
    var registerScrollButton = function registerScrollButton(state) {
      return function (position, dom) {
        return state.scrollButtons[position] = dom;
      };
    };
    return {
      tabsEl: undefined,
      tabRowEl: undefined,
      tabs: [], // {data, el}
      tabRow: undefined,
      tabIndicatorEl: undefined,
      selectedTabIndex: selectedTabIndex,
      previousSelectedTabIndex: undefined,
      managesScroll: attrs.scrollable && !polytheneCore.isTouch,
      scrollButtonAtStart: scrollButtonAtStart,
      scrollButtonAtEnd: scrollButtonAtEnd,
      scrollButtons: {
        start: undefined,
        end: undefined
      },
      registerTabButton: registerTabButton,
      registerScrollButton: registerScrollButton,
      isRTL: false,
      cleanUp: undefined, // set in onMount
      redrawOnUpdate: createStream.merge([selectedTabIndex, scrollButtonAtStart, scrollButtonAtEnd])
    };
  };

  var onMount = function onMount(vnode) {
    if (!vnode.dom) {
      return;
    }
    var dom = vnode.dom;
    var state = vnode.state;
    var attrs = vnode.attrs;

    state.tabsEl = dom;
    state.isRTL = polytheneCore.isRTL({ element: dom });
    if (!attrs.hideIndicator) {
      state.tabIndicatorEl = dom.querySelector("." + classes.indicator);
    }
    state.tabRowEl = dom.querySelector("." + classes.tabRow);

    var redrawLargestWidth = function redrawLargestWidth() {
      if (state.tabs && attrs.largestWidth) {
        var widths = state.tabs.map(function (tabData) {
          return tabData.dom.getBoundingClientRect().width;
        });
        var largest = widths.sort(sortByLargestWidth)[0];
        state.tabs.forEach(function (tabData) {
          return tabData.dom.style.width = largest + "px";
        });
      }
    };

    var redraw = function redraw() {
      return redrawLargestWidth(), setSelectedTab(state, attrs, state.selectedTabIndex(), false);
    };

    var handleFontEvent = function handleFontEvent(_ref) {
      var name = _ref.name;
      return name === "active" || name === "inactive" ? redraw() : null;
    };

    polytheneCore.subscribe("resize", redraw);
    polytheneCore.subscribe("webfontloader", handleFontEvent);

    state.cleanUp = function () {
      return polytheneCore.unsubscribe("resize", redraw), polytheneCore.unsubscribe("webfontloader", handleFontEvent);
    };

    // A promise can't resolve during the oncreate loop
    // The Mithril draw loop is synchronous - there is no delay between one this oncreate and the tab button's oncreate
    whenCreateDone().then(redraw);
  };

  var onUnMount = function onUnMount(_ref2) {
    var state = _ref2.state;
    return state.cleanUp();
  };

  var createProps = function createProps(vnode, _ref3) {
    var k = _ref3.keys;

    var state = vnode.state;
    var attrs = vnode.attrs;
    var autofit = attrs.scrollable || attrs.centered ? false : attrs.autofit ? true : false;

    // Keep selected tab up to date
    var index = getIndex(state, attrs);
    if (index !== undefined && state.previousSelectedTabIndex !== index) {
      setSelectedTab(state, attrs, index, true);
    }
    state.previousSelectedTabIndex = index;

    return _extends({}, polytheneCore.filterSupportedAttributes(attrs), {
      className: [classes.component, attrs.scrollable ? classes.scrollable : null, state.scrollButtonAtStart() ? classes.isAtStart : null, state.scrollButtonAtEnd() ? classes.isAtEnd : null, attrs.activeSelected ? classes.activeSelectable : null, autofit ? classes.isAutofit : null, attrs.compact ? classes.compactTabs : null, attrs.menu ? classes.isMenu : null, attrs.tone === "dark" ? "pe-dark-tone" : null, attrs.tone === "light" ? "pe-light-tone" : null, attrs.className || attrs[k.class]].join(" ")
    });
  };

  var createContent = function createContent(vnode, _ref4) {
    var h = _ref4.renderer,
        k = _ref4.keys,
        Tab = _ref4.Tab,
        ScrollButton = _ref4.ScrollButton;

    var state = vnode.state;
    var attrs = vnode.attrs;

    var buttons = attrs.content ? attrs.content : attrs.tabs ? attrs.tabs : attrs.children || vnode.children || [];

    if (buttons.length === 0) {
      console.error("No tabs specified"); // eslint-disable-line no-console
    }

    var tabRow = buttons.map(function () {
      var buttonOpts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var index = arguments[1];

      var buttonOptsCombined = _extends({}, buttonOpts, {
        // These options can be overridden by `all`
        selected: index === state.selectedTabIndex(),
        animateOnTap: attrs.animateOnTap !== false ? true : false
      }, attrs.all, {
        // Internal options, should not get overridden
        index: index,
        key: buttonOpts.key || "tab-" + index,
        register: state.registerTabButton(state),
        onSelect: function onSelect() {
          return setSelectedTab(state, attrs, index, attrs.noIndicatorSlide ? false : true);
        }
      });
      return h(Tab, buttonOptsCombined);
    });

    var scrollButtonAtStart = void 0,
        scrollButtonAtEnd = void 0;
    if (attrs.scrollable) {
      scrollButtonAtStart = h(ScrollButton, _extends({}, {
        key: "backward",
        icon: attrs.scrollIconBackward,
        className: classes.scrollButtonAtStart,
        position: "start",
        register: state.registerScrollButton(state),
        events: _defineProperty({}, k.onclick, function (e) {
          return handleScrollButtonClick(state, attrs, e, "backward");
        }),
        isRTL: state.isRTL
      }));
      scrollButtonAtEnd = h(ScrollButton, _extends({}, {
        key: "forward",
        icon: attrs.scrollIconForward,
        className: classes.scrollButtonAtEnd,
        position: "end",
        register: state.registerScrollButton(state),
        events: _defineProperty({}, k.onclick, function (e) {
          return handleScrollButtonClick(state, attrs, e, "forward");
        }),
        isRTL: state.isRTL
      }));
    }

    var tabIndicator = attrs.hideIndicator ? null : h("div", {
      key: "indicator",
      className: classes.indicator
    });

    return [attrs.scrollable ? scrollButtonAtStart : null, h("div", {
      key: "tabrow",
      className: [classes.tabRow, attrs.centered ? classes.tabRowCentered : null, attrs.scrollable ? classes.tabRowIndent : null].join(" ")
    }, [tabRow, tabIndicator]), attrs.scrollable ? scrollButtonAtEnd : null];
  };

  var tabs = /*#__PURE__*/Object.freeze({
    getInitialState: getInitialState,
    onMount: onMount,
    onUnMount: onUnMount,
    createProps: createProps,
    createContent: createContent
  });

  var _extends$1 = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  function _defineProperty$1(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  // Don't export 'element': it will be the wrapped Button component (set in polythene-xxx-tabs/tab)

  var onMount$1 = function onMount(vnode) {
    if (!vnode.dom) {
      return;
    }
    var dom = vnode.dom;
    var attrs = vnode.attrs;
    attrs.register(attrs.index, {
      attrs: attrs,
      dom: dom
    });
  };

  var createProps$1 = function createProps(vnode, _ref) {
    var h = _ref.renderer,
        k = _ref.keys,
        Icon = _ref.Icon;

    var attrs = vnode.attrs;
    // Let internal onclick function co-exist with passed button option
    attrs.events = attrs.events || {};
    attrs.events[k.onclick] = attrs.events[k.onclick] || function () {};
    return _extends$1({}, attrs, {
      content: h("div", { className: classes.tabContent }, [attrs.icon ? h(Icon, attrs.icon) : null, attrs.label ? h("div", { className: classes.label }, h("span", attrs.label)) : null]),
      className: [classes.tab, attrs.icon && attrs.label ? classes.tabHasIcon : null, attrs.className || attrs[k.class]].join(" "),
      selected: attrs.selected,
      wash: false,
      ripple: true,
      events: _extends$1({}, attrs.events, _defineProperty$1({}, k.onclick, function (e) {
        attrs.onSelect();
        attrs.events[k.onclick](e);
      }))
    });
  };

  var createContent$1 = function createContent(vnode) {
    return vnode.children;
  };

  var tab = /*#__PURE__*/Object.freeze({
    onMount: onMount$1,
    createProps: createProps$1,
    createContent: createContent$1
  });

  // Don't export 'element': it will be the wrapped IconButton component (set in polythene-xxx-tabs/scroll-button)

  var arrowBackward = "<svg width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"><path d=\"M15.41 7.41L14 6l-6 6 6 6 1.41-1.41L10.83 12z\"/></svg>";
  var arrowForward = "<svg width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"><path d=\"M10 6L8.59 7.41 13.17 12l-4.58 4.59L10 18l6-6z\"/></svg>";

  var onMount$2 = function onMount(vnode) {
    if (!vnode.dom) {
      return;
    }
    var dom = vnode.dom;
    var attrs = vnode.attrs;
    attrs.register(attrs.position, dom);
  };

  var createProps$2 = function createProps(vnode, _ref) {
    var h = _ref.renderer,
        k = _ref.keys;

    var attrs = vnode.attrs;
    var icon = attrs.position === "start" ? attrs.icon || { svg: { content: h.trust(attrs.isRTL ? arrowForward : arrowBackward) } } : attrs.icon || { svg: { content: h.trust(attrs.isRTL ? arrowBackward : arrowForward) } };
    return {
      className: [classes.scrollButton, attrs.className || attrs[k.class]].join(" "),
      icon: icon,
      ripple: { center: true },
      events: attrs.events
    };
  };

  var scrollButton = /*#__PURE__*/Object.freeze({
    onMount: onMount$2,
    createProps: createProps$2
  });

  exports.coreTabs = tabs;
  exports.coreTab = tab;
  exports.coreScrollButton = scrollButton;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=polythene-core-tabs.js.map
